@@ -25,6 +25,11 @@
 #define SETTINGS_SCHEMA "org.mate.SettingsDaemon.plugins.housekeeping"
 #define SETTINGS_IGNORE_PATHS "ignore-paths"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 enum
 {
         PROP_0,
@@ -153,8 +158,7 @@ ignore_check_button_toggled_cb (GtkToggleButton *button,
         GSettings *settings;
         gchar **settings_list;
         GSList *ignore_paths = NULL;
-        GError *error = NULL;
-        gboolean ignore, ret, updated;
+        gboolean ignore, updated;
         gint i;
 
         settings = g_settings_new (SETTINGS_SCHEMA);
@@ -215,19 +219,34 @@ msd_ldsm_dialog_init (MsdLdsmDialog *dialog)
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
         /* Create the image */
-        image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
+        image = gtk_image_new_from_icon_name ("dialog-warning", GTK_ICON_SIZE_DIALOG);
+#if GTK_CHECK_VERSION (3, 0, 0)
+        gtk_widget_set_halign (image, GTK_ALIGN_START);
+        gtk_widget_set_valign (image, GTK_ALIGN_END);
+#else
         gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+#endif
 
         /* Create the labels */
         dialog->priv->primary_label = gtk_label_new (NULL);	
         gtk_label_set_line_wrap (GTK_LABEL (dialog->priv->primary_label), TRUE);
         gtk_label_set_single_line_mode (GTK_LABEL (dialog->priv->primary_label), FALSE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+        gtk_label_set_xalign (GTK_LABEL (dialog->priv->primary_label), 0.0);
+        gtk_label_set_yalign (GTK_LABEL (dialog->priv->primary_label), 0.0);
+#else
         gtk_misc_set_alignment (GTK_MISC (dialog->priv->primary_label), 0.0, 0.0);
+#endif
 	
         dialog->priv->secondary_label = gtk_label_new (NULL);
         gtk_label_set_line_wrap (GTK_LABEL (dialog->priv->secondary_label), TRUE);
         gtk_label_set_single_line_mode (GTK_LABEL (dialog->priv->secondary_label), FALSE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+        gtk_label_set_xalign (GTK_LABEL (dialog->priv->secondary_label), 0.0);
+        gtk_label_set_yalign (GTK_LABEL (dialog->priv->secondary_label), 0.0);
+#else
         gtk_misc_set_alignment (GTK_MISC (dialog->priv->secondary_label), 0.0, 0.0);
+#endif
 
         /* Create the check button to ignore future warnings */
         dialog->priv->ignore_check_button = gtk_check_button_new ();
@@ -439,7 +458,7 @@ msd_ldsm_dialog_new (gboolean     other_usable_partitions,
                 button_empty_trash = gtk_dialog_add_button (GTK_DIALOG (dialog),
                                                             _("Empty Trash"),
                                                             MSD_LDSM_DIALOG_RESPONSE_EMPTY_TRASH);
-                empty_trash_image = gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_BUTTON);
+                empty_trash_image = gtk_image_new_from_icon_name ("edit-clear", GTK_ICON_SIZE_BUTTON);
                 gtk_button_set_image (GTK_BUTTON (button_empty_trash), empty_trash_image);
         }
 	
