@@ -70,9 +70,12 @@
 #define KEY_TOUCHPAD_ONE_FINGER_TAP      "tap-button-one-finger"
 #define KEY_TOUCHPAD_TWO_FINGER_TAP      "tap-button-two-finger"
 #define KEY_TOUCHPAD_THREE_FINGER_TAP    "tap-button-three-finger"
-#define KEY_TOUCHPAD_SCROLL_METHOD       "scroll-method"
-#define KEY_TOUCHPAD_PAD_HORIZ_SCROLL    "horiz-scroll-enabled"
+#define KEY_VERT_EDGE_SCROLL             "vertical-edge-scrolling"
+#define KEY_HORIZ_EDGE_SCROLL            "horizontal-edge-scrolling"
+#define KEY_VERT_TWO_FINGER_SCROLL       "vertical-two-finger-scrolling"
+#define KEY_HORIZ_TWO_FINGER_SCROLL      "horizontal-two-finger-scrolling"
 #define KEY_TOUCHPAD_ENABLED             "touchpad-enabled"
+
 #endif
 
 /* FIXME: currently there is no mate-mousetweaks, so I comment this
@@ -108,82 +111,16 @@ G_DEFINE_TYPE (MsdMouseManager, msd_mouse_manager, G_TYPE_OBJECT)
 
 static gpointer manager_object = NULL;
 
-static void
-msd_mouse_manager_set_property (GObject        *object,
-                               guint           prop_id,
-                               const GValue   *value,
-                               GParamSpec     *pspec)
-{
-        MsdMouseManager *self;
-
-        self = MSD_MOUSE_MANAGER (object);
-
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static void
-msd_mouse_manager_get_property (GObject        *object,
-                               guint           prop_id,
-                               GValue         *value,
-                               GParamSpec     *pspec)
-{
-        MsdMouseManager *self;
-
-        self = MSD_MOUSE_MANAGER (object);
-
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static GObject *
-msd_mouse_manager_constructor (GType                  type,
-                              guint                  n_construct_properties,
-                              GObjectConstructParam *construct_properties)
-{
-        MsdMouseManager      *mouse_manager;
-        MsdMouseManagerClass *klass;
-
-        klass = MSD_MOUSE_MANAGER_CLASS (g_type_class_peek (MSD_TYPE_MOUSE_MANAGER));
-
-        mouse_manager = MSD_MOUSE_MANAGER (G_OBJECT_CLASS (msd_mouse_manager_parent_class)->constructor (type,
-                                                                                                      n_construct_properties,
-                                                                                                      construct_properties));
-
-        return G_OBJECT (mouse_manager);
-}
-
-static void
-msd_mouse_manager_dispose (GObject *object)
-{
-        MsdMouseManager *mouse_manager;
-
-        mouse_manager = MSD_MOUSE_MANAGER (object);
-
-        G_OBJECT_CLASS (msd_mouse_manager_parent_class)->dispose (object);
-}
-
 static void
 msd_mouse_manager_class_init (MsdMouseManagerClass *klass)
 {
         GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->get_property = msd_mouse_manager_get_property;
-        object_class->set_property = msd_mouse_manager_set_property;
-        object_class->constructor = msd_mouse_manager_constructor;
-        object_class->dispose = msd_mouse_manager_dispose;
         object_class->finalize = msd_mouse_manager_finalize;
 
         g_type_class_add_private (klass, sizeof (MsdMouseManagerPrivate));
 }
 
-
 #ifdef HAVE_X11_EXTENSIONS_XINPUT_H
 static gboolean
 supports_xinput_devices (void)
@@ -302,7 +239,11 @@ touchpad_has_single_button (XDevice *device)
         if (rc == Success)
                 XFree (data);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+        gdk_error_trap_pop_ignored ();
+#else
         gdk_error_trap_pop ();
+#endif
 
         return is_single_button;
 }
@@ -568,7 +509,11 @@ set_middle_button (MsdMouseManager *manager,
                         XChangeDeviceProperty (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()),
                                                device, prop, type, format, PropModeReplace, data, nitems);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+                        gdk_error_trap_pop_ignored ();
+#else
                         gdk_error_trap_pop ();
+#endif
                 }
 
                 XFree (data);
@@ -591,7 +536,7 @@ have_program_in_path (const char *name)
         return result;
 }
 
-static int
+static void
 set_disable_w_typing (MsdMouseManager *manager, gboolean state)
 {
 
@@ -600,7 +545,7 @@ set_disable_w_typing (MsdMouseManager *manager, gboolean state)
                 char *args[6];
 
                 if (manager->priv->syndaemon_spawned)
-                        return 0;
+                        return;
 
                 args[0] = "syndaemon";
                 args[1] = "-i";
@@ -610,7 +555,7 @@ set_disable_w_typing (MsdMouseManager *manager, gboolean state)
                 args[5] = NULL;
 
                 if (!have_program_in_path (args[0]))
-                        return 0;
+                        return;
 
                 g_spawn_async (g_get_home_dir (), args, NULL,
                                 G_SPAWN_SEARCH_PATH, NULL, NULL,
@@ -629,8 +574,6 @@ set_disable_w_typing (MsdMouseManager *manager, gboolean state)
                 g_spawn_close_pid (manager->priv->syndaemon_pid);
                 manager->priv->syndaemon_spawned = FALSE;
         }
-
-        return 0;
 }
 
 #ifdef HAVE_X11_EXTENSIONS_XINPUT_H
@@ -795,136 +738,68 @@ set_natural_scroll (MsdMouseManager * manager)
         XFreeDeviceList (devicelist);
 }
 
-static int
-set_horiz_scroll (gboolean state)
+static void
+synaptics_set_bool (const char * property_name, int property_index, gboolean enabled)
 {
-        int numdevices, i, rc;
-        XDeviceInfo *devicelist = XListInputDevices (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), &numdevices);
-        XDevice *device;
-        Atom act_type, prop_edge, prop_twofinger;
-        int act_format;
-        unsigned long nitems, bytes_after;
-        unsigned char *data;
+    int numdevices, i, rc;
+    XDeviceInfo *devicelist = XListInputDevices (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), &numdevices);
+    XDevice *device;
+    Atom act_type, property;
+    int act_format;
+    unsigned long nitems, bytes_after;
+    unsigned char *data;
 
-        if (devicelist == NULL)
-                return 0;
+    if (devicelist == NULL)
+        return;
 
-        prop_edge = XInternAtom (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), "Synaptics Edge Scrolling", False);
-        prop_twofinger = XInternAtom (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), "Synaptics Two-Finger Scrolling", False);
+    property = XInternAtom (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), property_name, False);
 
-        if (!prop_edge || !prop_twofinger)
-                return 0;
+    if (!property)
+        return;
 
-        for (i = 0; i < numdevices; i++) {
-                if ((device = device_is_touchpad (devicelist[i]))) {
-                        gdk_error_trap_push ();
-                        rc = XGetDeviceProperty (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device,
-                                                prop_edge, 0, 1, False,
-                                                XA_INTEGER, &act_type, &act_format, &nitems,
-                                                &bytes_after, &data);
-                        if (rc == Success && act_type == XA_INTEGER &&
-                                act_format == 8 && nitems >= 2) {
-                                data[1] = (state && data[0]);
-                                XChangeDeviceProperty (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device,
-                                                        prop_edge, XA_INTEGER, 8,
-                                                        PropModeReplace, data, nitems);
-                        }
+    int value = 0;
+    if (enabled) {
+    	value = 1;
+    }
 
-                        XFree (data);
+    for (i = 0; i < numdevices; i++) {
+        if ((device = device_is_touchpad (devicelist[i]))) {
+            gdk_error_trap_push ();
+            rc = XGetDeviceProperty (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device,
+                                    property, 0, 1, False,
+                                    XA_INTEGER, &act_type, &act_format, &nitems,
+                                    &bytes_after, &data);
+            if (rc == Success && act_type == XA_INTEGER && act_format == 8 && nitems > property_index) {
+                data[property_index] = value;
+                XChangeDeviceProperty (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device,
+                                        property, XA_INTEGER, 8,
+                                        PropModeReplace, data, nitems);
+            }
 
-                        rc = XGetDeviceProperty (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device,
-                                                prop_twofinger, 0, 1, False,
-                                                XA_INTEGER, &act_type, &act_format, &nitems,
-                                                &bytes_after, &data);
-                        if (rc == Success && act_type == XA_INTEGER &&
-                                act_format == 8 && nitems >= 2) {
-                                data[1] = (state && data[0]);
-                                XChangeDeviceProperty (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device,
-                                                        prop_twofinger, XA_INTEGER, 8,
-                                                        PropModeReplace, data, nitems);
-                        }
+            XFree (data);
 
-                        XFree (data);
-                        XCloseDevice (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device);
-                        if (gdk_error_trap_pop ()) {
-                                g_warning ("Error in setting horiz scroll on \"%s\"", devicelist[i].name);
-                                continue;
-                        }
-                }
+            XCloseDevice (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device);
+            if (gdk_error_trap_pop ()) {
+                g_warning ("Error while setting %s on \"%s\"", property_name, devicelist[i].name);
+                continue;
+            }
         }
+    }
 
-        XFreeDeviceList (devicelist);
-        return 0;
+    XFreeDeviceList (devicelist);
 }
 
 
-/**
- * Scroll methods are: 0 - disabled, 1 - edge scrolling, 2 - twofinger
- * scrolling
- */
-static int
-set_edge_scroll (int method)
+static void
+set_scrolling (GSettings *settings)
 {
-        int numdevices, i, rc;
-        XDeviceInfo *devicelist = XListInputDevices (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), &numdevices);
-        XDevice *device;
-        Atom act_type, prop_edge, prop_twofinger;
-        int act_format;
-        unsigned long nitems, bytes_after;
-        unsigned char *data;
-
-        if (devicelist == NULL)
-                return 0;
-
-        prop_edge = XInternAtom (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), "Synaptics Edge Scrolling", False);
-        prop_twofinger = XInternAtom (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), "Synaptics Two-Finger Scrolling", False);
-
-        if (!prop_edge || !prop_twofinger)
-                return 0;
-
-        for (i = 0; i < numdevices; i++) {
-                if ((device = device_is_touchpad (devicelist[i]))) {
-                        gdk_error_trap_push ();
-                        rc = XGetDeviceProperty (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device,
-                                                prop_edge, 0, 1, False,
-                                                XA_INTEGER, &act_type, &act_format, &nitems,
-                                                &bytes_after, &data);
-                        if (rc == Success && act_type == XA_INTEGER &&
-                                act_format == 8 && nitems >= 2) {
-                                data[0] = (method == 1) ? 1 : 0;
-                                XChangeDeviceProperty (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device,
-                                                        prop_edge, XA_INTEGER, 8,
-                                                        PropModeReplace, data, nitems);
-                        }
-
-                        XFree (data);
-
-                        rc = XGetDeviceProperty (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device,
-                                                prop_twofinger, 0, 1, False,
-                                                XA_INTEGER, &act_type, &act_format, &nitems,
-                                                &bytes_after, &data);
-                        if (rc == Success && act_type == XA_INTEGER &&
-                                act_format == 8 && nitems >= 2) {
-                                data[0] = (method == 2) ? 1 : 0;
-                                XChangeDeviceProperty (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device,
-                                                        prop_twofinger, XA_INTEGER, 8,
-                                                        PropModeReplace, data, nitems);
-                        }
-
-                        XFree (data);
-                        XCloseDevice (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device);
-                        if (gdk_error_trap_pop ()) {
-                                g_warning ("Error in setting edge scroll on \"%s\"", devicelist[i].name);
-                                continue;
-                        }
-                }
-        }
-
-        XFreeDeviceList (devicelist);
-        return 0;
+    synaptics_set_bool ("Synaptics Edge Scrolling", 0, g_settings_get_boolean (settings, KEY_VERT_EDGE_SCROLL));
+    synaptics_set_bool ("Synaptics Edge Scrolling", 1, g_settings_get_boolean (settings, KEY_HORIZ_EDGE_SCROLL));
+    synaptics_set_bool ("Synaptics Two-Finger Scrolling", 0, g_settings_get_boolean (settings, KEY_VERT_TWO_FINGER_SCROLL));
+    synaptics_set_bool ("Synaptics Two-Finger Scrolling", 1, g_settings_get_boolean (settings, KEY_HORIZ_TWO_FINGER_SCROLL));
 }
 
-static int
+static void
 set_touchpad_enabled (gboolean state)
 {
         int numdevices, i;
@@ -933,12 +808,12 @@ set_touchpad_enabled (gboolean state)
         Atom prop_enabled;
 
         if (devicelist == NULL)
-                return 0;
+                return;
 
         prop_enabled = XInternAtom (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), "Device Enabled", False);
 
         if (!prop_enabled)
-            return 0;
+            return;
 
         for (i = 0; i < numdevices; i++) {
                 if ((device = device_is_touchpad (devicelist[i]))) {
@@ -959,7 +834,6 @@ set_touchpad_enabled (gboolean state)
         }
 
         XFreeDeviceList (devicelist);
-        return 0;
 }
 #endif
 
@@ -1073,8 +947,7 @@ set_mouse_settings (MsdMouseManager *manager)
 #ifdef HAVE_X11_EXTENSIONS_XINPUT_H
         set_tap_to_click (manager);
         set_click_actions (manager);
-        set_edge_scroll (g_settings_get_int (manager->priv->settings_touchpad, KEY_TOUCHPAD_SCROLL_METHOD));
-        set_horiz_scroll (g_settings_get_boolean (manager->priv->settings_touchpad, KEY_TOUCHPAD_PAD_HORIZ_SCROLL));
+        set_scrolling (manager->priv->settings_touchpad);
         set_natural_scroll (manager);
         set_touchpad_enabled (g_settings_get_boolean (manager->priv->settings_touchpad, KEY_TOUCHPAD_ENABLED));
 #endif
@@ -1106,13 +979,10 @@ mouse_callback (GSettings          *settings,
                 set_tap_to_click (manager);
         } else if (g_strcmp0 (key, KEY_TOUCHPAD_THREE_FINGER_TAP) == 0) {
                 set_tap_to_click (manager);
-        } else if (g_strcmp0 (key, KEY_TOUCHPAD_SCROLL_METHOD) == 0) {
-                set_edge_scroll (g_settings_get_int (settings, key));
-                set_horiz_scroll (g_settings_get_boolean (settings, KEY_TOUCHPAD_PAD_HORIZ_SCROLL));
+        } else if (g_strcmp0 (key, KEY_VERT_EDGE_SCROLL) == 0 || g_strcmp0 (key, KEY_HORIZ_EDGE_SCROLL) == 0 || g_strcmp0 (key, KEY_VERT_TWO_FINGER_SCROLL) == 0 || g_strcmp0 (key, KEY_HORIZ_TWO_FINGER_SCROLL) == 0) {
+                set_scrolling (manager->priv->settings_touchpad);
         } else if (g_str_equal (key, KEY_TOUCHPAD_NATURAL_SCROLL)) {
                 set_natural_scroll (manager);
-        } else if (g_strcmp0 (key, KEY_TOUCHPAD_PAD_HORIZ_SCROLL) == 0) {
-                set_horiz_scroll (g_settings_get_boolean (settings, key));
 #endif
         } else if (g_strcmp0 (key, KEY_MOUSE_LOCATE_POINTER) == 0) {
                 set_locate_pointer (manager, g_settings_get_boolean (settings, key));
@@ -1170,8 +1040,7 @@ msd_mouse_manager_idle_cb (MsdMouseManager *manager)
 #ifdef HAVE_X11_EXTENSIONS_XINPUT_H
         set_tap_to_click (manager);
         set_click_actions (manager);
-        set_edge_scroll (g_settings_get_int (manager->priv->settings_touchpad, KEY_TOUCHPAD_SCROLL_METHOD));
-        set_horiz_scroll (g_settings_get_boolean (manager->priv->settings_touchpad, KEY_TOUCHPAD_PAD_HORIZ_SCROLL));
+        set_scrolling (manager->priv->settings_touchpad);
         set_natural_scroll (manager);
         set_touchpad_enabled (g_settings_get_boolean (manager->priv->settings_touchpad, KEY_TOUCHPAD_ENABLED));
 #endif
