@@ -53,10 +53,6 @@
 #include "mate-settings-profile.h"
 #include "msd-xrandr-manager.h"
 
-#ifndef HOST_NAME_MAX
-#define HOST_NAME_MAX   255
-#endif
-
 #define MSD_XRANDR_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MSD_TYPE_XRANDR_MANAGER, MsdXrandrManagerPrivate))
 
 #define CONF_SCHEMA                                    "org.mate.SettingsDaemon.plugins.xrandr"
@@ -193,7 +189,7 @@ log_output (MateRROutputInfo *output)
         gchar *name = mate_rr_output_info_get_name (output);
         gchar *display_name = mate_rr_output_info_get_display_name (output);
 
-	log_msg ("        %s: ", name ? name : "unknown");
+        log_msg ("        %s: ", name ? name : "unknown");
 
         if (mate_rr_output_info_is_connected (output)) {
                 if (mate_rr_output_info_is_active (output)) {
@@ -699,7 +695,7 @@ static void
 print_configuration (MateRRConfig *config, const char *header)
 {
         int i;
-	MateRROutputInfo **outputs;
+        MateRROutputInfo **outputs;
 
         g_print ("=== %s Configuration ===\n", header);
         if (!config) {
@@ -708,7 +704,7 @@ print_configuration (MateRRConfig *config, const char *header)
         }
 
         outputs = mate_rr_config_get_outputs (config);
-	for (i = 0; outputs[i] != NULL; ++i)
+        for (i = 0; outputs[i] != NULL; ++i)
                 print_output (outputs[i]);
 }
 
@@ -733,7 +729,7 @@ static MateRRConfig *
 make_clone_setup (MateRRScreen *screen)
 {
         MateRRConfig *result;
-	MateRROutputInfo **outputs;
+        MateRROutputInfo **outputs;
         int width, height;
         int i;
 
@@ -741,7 +737,7 @@ make_clone_setup (MateRRScreen *screen)
                 return NULL;
 
         result = mate_rr_config_new_current (screen, NULL);
-	outputs = mate_rr_config_get_outputs (result);
+        outputs = mate_rr_config_get_outputs (result);
 
         for (i = 0; outputs[i] != NULL; ++i) {
                 MateRROutputInfo *info = outputs[i];
@@ -860,7 +856,7 @@ make_laptop_setup (MateRRScreen *screen)
 {
         /* Turn on the laptop, disable everything else */
         MateRRConfig *result = mate_rr_config_new_current (screen, NULL);
-	MateRROutputInfo **outputs = mate_rr_config_get_outputs (result);
+        MateRROutputInfo **outputs = mate_rr_config_get_outputs (result);
         int i;
 
         for (i = 0; outputs[i] != NULL; ++i) {
@@ -889,7 +885,6 @@ make_laptop_setup (MateRRScreen *screen)
          * one connected "laptop" screen?
          */
         return result;
-
 }
 
 static int
@@ -948,7 +943,7 @@ make_other_setup (MateRRScreen *screen)
          */
 
         MateRRConfig *result = mate_rr_config_new_current (screen, NULL);
-	MateRROutputInfo **outputs = mate_rr_config_get_outputs (result);
+        MateRROutputInfo **outputs = mate_rr_config_get_outputs (result);
         int i;
 
         for (i = 0; outputs[i] != NULL; ++i) {
@@ -1116,7 +1111,7 @@ error_message (MsdXrandrManager *mgr, const char *primary_text, GError *error_to
 #else
         GtkWidget *dialog;
 
-	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+        dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
                                          "%s", primary_text);
         gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s",
                                                   error_to_display ? error_to_display->message : secondary_text);
@@ -1235,7 +1230,7 @@ static MateRROutputInfo *
 get_laptop_output_info (MateRRScreen *screen, MateRRConfig *config)
 {
         int i;
-	MateRROutputInfo **outputs = mate_rr_config_get_outputs (config);
+        MateRROutputInfo **outputs = mate_rr_config_get_outputs (config);
 
         for (i = 0; outputs[i] != NULL; i++) {
                 if (is_laptop (screen, outputs[i]))
@@ -1379,7 +1374,7 @@ auto_configure_outputs (MsdXrandrManager *manager, guint32 timestamp)
 {
         MsdXrandrManagerPrivate *priv = manager->priv;
         MateRRConfig *config;
-	MateRROutputInfo **outputs;
+        MateRROutputInfo **outputs;
         int i;
         GList *just_turned_on;
         GList *l;
@@ -1402,7 +1397,7 @@ auto_configure_outputs (MsdXrandrManager *manager, guint32 timestamp)
          */
 
         just_turned_on = NULL;
-	outputs = mate_rr_config_get_outputs (config);
+        outputs = mate_rr_config_get_outputs (config);
 
         for (i = 0; outputs[i] != NULL; i++) {
                 MateRROutputInfo *output = outputs[i];
@@ -1637,17 +1632,17 @@ run_display_capplet (GtkWidget *widget)
 
         error = NULL;
         if (!mate_gdk_spawn_command_line_on_screen (screen, MSD_XRANDR_DISPLAY_CAPPLET, &error)) {
-		GtkWidget *dialog;
+                GtkWidget *dialog;
 
-		dialog = gtk_message_dialog_new_with_markup (NULL, 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                dialog = gtk_message_dialog_new_with_markup (NULL, 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
                                                              "<span weight=\"bold\" size=\"larger\">"
                                                              "Display configuration could not be run"
                                                              "</span>\n\n"
                                                              "%s", error->message);
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
+                gtk_dialog_run (GTK_DIALOG (dialog));
+                gtk_widget_destroy (dialog);
 
-		g_error_free (error);
+                g_error_free (error);
         }
 }
 
@@ -1811,7 +1806,7 @@ make_menu_item_for_output_title (MsdXrandrManager *manager, MateRROutputInfo *ou
         GtkWidget *item;
         GtkWidget *label;
         char *str;
-	GdkColor black = { 0, 0, 0, 0 };
+        GdkColor black = { 0, 0, 0, 0 };
 
         item = gtk_menu_item_new ();
 
@@ -1823,14 +1818,19 @@ make_menu_item_for_output_title (MsdXrandrManager *manager, MateRROutputInfo *ou
         gtk_label_set_markup (GTK_LABEL (label), str);
         g_free (str);
 
-	/* Make the label explicitly black.  We don't want it to follow the
-	 * theme's colors, since the label is always shown against a light
-	 * pastel background.  See bgo#556050
-	 */
-	gtk_widget_modify_fg (label, gtk_widget_get_state (label), &black);
+        /* Make the label explicitly black.  We don't want it to follow the
+         * theme's colors, since the label is always shown against a light
+         * pastel background.  See bgo#556050
+         */
+        gtk_widget_modify_fg (label, gtk_widget_get_state (label), &black);
 
         /* Add padding around the label to fit the box that we'll draw for color-coding */
+#if GTK_CHECK_VERSION (3, 16, 0)
+        gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+        gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
         gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
         gtk_misc_set_padding (GTK_MISC (label),
                               OUTPUT_TITLE_ITEM_BORDER + OUTPUT_TITLE_ITEM_PADDING,
                               OUTPUT_TITLE_ITEM_BORDER + OUTPUT_TITLE_ITEM_PADDING);
@@ -1954,9 +1954,9 @@ output_rotation_item_activate_cb (GtkCheckMenuItem *item, gpointer data)
         MateRRRotation rotation;
         GError *error;
 
-	/* Not interested in deselected items */
-	if (!gtk_check_menu_item_get_active (item))
-		return;
+        /* Not interested in deselected items */
+        if (!gtk_check_menu_item_get_active (item))
+                return;
 
         ensure_current_configuration_is_saved ();
 
@@ -2208,15 +2208,15 @@ on_config_changed (GSettings        *settings,
                    gchar            *key,
                    MsdXrandrManager *manager)
 {
-	if (g_strcmp0 (key, CONF_KEY_SHOW_NOTIFICATION_ICON) == 0)
-		start_or_stop_icon (manager);
+        if (g_strcmp0 (key, CONF_KEY_SHOW_NOTIFICATION_ICON) == 0)
+                start_or_stop_icon (manager);
 }
 
 static gboolean
 apply_intended_configuration (MsdXrandrManager *manager, const char *intended_filename, guint32 timestamp)
 {
         GError *my_error;
-	gboolean result;
+        gboolean result;
 
         my_error = NULL;
         result = apply_configuration_from_filename (manager, intended_filename, TRUE, timestamp, &my_error);
@@ -2236,24 +2236,24 @@ apply_intended_configuration (MsdXrandrManager *manager, const char *intended_fi
 static void
 apply_default_boot_configuration (MsdXrandrManager *mgr, guint32 timestamp)
 {
-	MsdXrandrManagerPrivate *priv = mgr->priv;
-	MateRRScreen *screen = priv->rw_screen;
-   	MateRRConfig *config;
-   	gboolean turn_on_external, turn_on_laptop;
+        MsdXrandrManagerPrivate *priv = mgr->priv;
+        MateRRScreen *screen = priv->rw_screen;
+        MateRRConfig *config;
+        gboolean turn_on_external, turn_on_laptop;
 
         turn_on_external =
                 g_settings_get_boolean (mgr->priv->settings, CONF_KEY_TURN_ON_EXTERNAL_MONITORS_AT_STARTUP);
         turn_on_laptop =
                 g_settings_get_boolean (mgr->priv->settings, CONF_KEY_TURN_ON_LAPTOP_MONITOR_AT_STARTUP);
 
-	if (turn_on_external && turn_on_laptop)
-		config = make_clone_setup (screen);
-	else if (!turn_on_external && turn_on_laptop)
-		config = make_laptop_setup (screen);
-	else if (turn_on_external && !turn_on_laptop)
-		config = make_other_setup (screen);
-	else
-		config = make_laptop_setup (screen);
+        if (turn_on_external && turn_on_laptop)
+                config = make_clone_setup (screen);
+        else if (!turn_on_external && turn_on_laptop)
+                config = make_laptop_setup (screen);
+        else if (turn_on_external && !turn_on_laptop)
+                config = make_other_setup (screen);
+        else
+                config = make_laptop_setup (screen);
 
         if (config) {
                 apply_configuration_and_display_error (mgr, config, timestamp);
@@ -2308,7 +2308,6 @@ apply_stored_configuration_at_startup (MsdXrandrManager *manager, guint32 timest
         success = apply_intended_configuration (manager, intended_filename, timestamp);
 
 out:
-
         if (my_error)
                 g_error_free (my_error);
 
@@ -2377,7 +2376,11 @@ msd_xrandr_manager_start (MsdXrandrManager *manager,
                           True, GrabModeAsync, GrabModeAsync);
 
                 gdk_flush ();
+#if GTK_CHECK_VERSION (3, 0, 0)
+                gdk_error_trap_pop_ignored ();
+#else
                 gdk_error_trap_pop ();
+#endif
         }
 
         if (manager->priv->rotate_windows_keycode) {
@@ -2389,7 +2392,11 @@ msd_xrandr_manager_start (MsdXrandrManager *manager,
                           True, GrabModeAsync, GrabModeAsync);
 
                 gdk_flush ();
+#if GTK_CHECK_VERSION (3, 0, 0)
+                gdk_error_trap_pop_ignored ();
+#else
                 gdk_error_trap_pop ();
+#endif
         }
 
         show_timestamps_dialog (manager, "Startup");
@@ -2428,7 +2435,11 @@ msd_xrandr_manager_stop (MsdXrandrManager *manager)
                             manager->priv->switch_video_mode_keycode, AnyModifier,
                             gdk_x11_get_default_root_xwindow());
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+                gdk_error_trap_pop_ignored ();
+#else
                 gdk_error_trap_pop ();
+#endif
         }
 
         if (manager->priv->rotate_windows_keycode) {
@@ -2438,7 +2449,11 @@ msd_xrandr_manager_stop (MsdXrandrManager *manager)
                             manager->priv->rotate_windows_keycode, AnyModifier,
                             gdk_x11_get_default_root_xwindow());
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+                gdk_error_trap_pop_ignored ();
+#else
                 gdk_error_trap_pop ();
+#endif
         }
 
         gdk_window_remove_filter (gdk_get_default_root_window (),
@@ -2467,76 +2482,11 @@ msd_xrandr_manager_stop (MsdXrandrManager *manager)
         log_close ();
 }
 
-static void
-msd_xrandr_manager_set_property (GObject        *object,
-                               guint           prop_id,
-                               const GValue   *value,
-                               GParamSpec     *pspec)
-{
-        MsdXrandrManager *self;
-
-        self = MSD_XRANDR_MANAGER (object);
-
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static void
-msd_xrandr_manager_get_property (GObject        *object,
-                               guint           prop_id,
-                               GValue         *value,
-                               GParamSpec     *pspec)
-{
-        MsdXrandrManager *self;
-
-        self = MSD_XRANDR_MANAGER (object);
-
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static GObject *
-msd_xrandr_manager_constructor (GType                  type,
-                              guint                  n_construct_properties,
-                              GObjectConstructParam *construct_properties)
-{
-        MsdXrandrManager      *xrandr_manager;
-        MsdXrandrManagerClass *klass;
-
-        klass = MSD_XRANDR_MANAGER_CLASS (g_type_class_peek (MSD_TYPE_XRANDR_MANAGER));
-
-        xrandr_manager = MSD_XRANDR_MANAGER (G_OBJECT_CLASS (msd_xrandr_manager_parent_class)->constructor (type,
-                                                                                                      n_construct_properties,
-                                                                                                      construct_properties));
-
-        return G_OBJECT (xrandr_manager);
-}
-
-static void
-msd_xrandr_manager_dispose (GObject *object)
-{
-        MsdXrandrManager *xrandr_manager;
-
-        xrandr_manager = MSD_XRANDR_MANAGER (object);
-
-        G_OBJECT_CLASS (msd_xrandr_manager_parent_class)->dispose (object);
-}
-
 static void
 msd_xrandr_manager_class_init (MsdXrandrManagerClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->get_property = msd_xrandr_manager_get_property;
-        object_class->set_property = msd_xrandr_manager_set_property;
-        object_class->constructor = msd_xrandr_manager_constructor;
-        object_class->dispose = msd_xrandr_manager_dispose;
         object_class->finalize = msd_xrandr_manager_finalize;
 
         dbus_g_object_type_install_info (MSD_TYPE_XRANDR_MANAGER, &dbus_glib_msd_xrandr_manager_object_info);
